==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/DTPOutputStream.h <==
// abstract class gnu.java.net.protocol.ftp.DTPOutputStream

// class file dependencies
// @dep_class 8f86c2f0d8bbeb13 gnu_java_net_protocol_ftp_DTPOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_DTPOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_DTPOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method$_init$6e5b27297a1ccb9b(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *);
extern void _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method$setTransferComplete$cd2138d5d98b31f0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method_info$setTransferComplete$cd2138d5d98b31f0;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *);
	void	(*setTransferComplete$cd2138d5d98b31f0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *, jboolean);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	gnu_java_net_protocol_ftp_DTPOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs {
	struct _jc_object	*dtp;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs {
	jboolean	transferComplete;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype _jc_gnu_java_net_protocol_ftp_DTPOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_DTPOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_DTPOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_DTPOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/DTPOutputStream.h <==
// abstract class gnu.java.net.protocol.ftp.DTPOutputStream

// class file dependencies
// @dep_class 8f86c2f0d8bbeb13 gnu_java_net_protocol_ftp_DTPOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_DTPOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_DTPOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method$_init$6e5b27297a1ccb9b(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method$setTransferComplete$cd2138d5d98b31f0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPOutputStream$method_info$setTransferComplete$cd2138d5d98b31f0;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *) _JC_JCNI_ATTR;
	void	(*setTransferComplete$cd2138d5d98b31f0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	gnu_java_net_protocol_ftp_DTPOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs {
	struct _jc_object	*dtp;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs {
	jboolean	transferComplete;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_DTPOutputStream$vtype _jc_gnu_java_net_protocol_ftp_DTPOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_DTPOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_DTPOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_DTPOutputStream_H_ */
